
========
MU Build
========

About
=====

Provided with config file, mu_build fetches/clones dependencies then compiles every module in each package.
This is the entrypoint into the CI / Pull Request build and test infrastructure.

Version History
===============

0.3.0
-----

Updated documentation and release process.  Transition to Beta.

< 0.3.0
-------

Alpha development